<?php
/**
 * FiloBlu srl
 *
 * @category   FiloBlu
 * @package    FiloBlu_ReCaptcha
 * @copyright  FiloBlu srl (http://www.filoblu.com)
 *
 */

namespace FiloBlu\ReCaptcha\Observer\Frontend;

use Magento\Framework\Event\Observer;
use Magento\Framework\Event\ObserverInterface;
use Magento\Customer\Model\Session;
use Magento\Framework\UrlInterface;
use FiloBlu\ReCaptcha\Api\ValidateInterface;
use FiloBlu\ReCaptcha\Helper\Data;
use Magento\Framework\Message\ManagerInterface;
use Magento\Framework\App\ActionFlag;
use Magento\Framework\App\Action\Action;
use Magento\Framework\App\Config\ScopeConfigInterface;

class NewsletterLandingActionObserver implements ObserverInterface
{
    protected $validateInterface;
    protected $helperData;
    protected $messageManager;
    protected $actionFlag;
    protected $urlInterface;
    protected $customerSession;
    protected $scopeConfig;
    protected $jsonResultFactory;

    public function __construct(
        ValidateInterface $validateInterface,
        Data $helperData,
        ManagerInterface $messageManager,
        Session $customerSession,
        ActionFlag $actionFlag,
        UrlInterface $urlInterface,
        \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig,
        \Magento\Framework\Controller\Result\JsonFactory $resultJsonFactory
    ) {
        $this->validateInterface = $validateInterface;
        $this->helperData = $helperData;
        $this->messageManager = $messageManager;
        $this->actionFlag = $actionFlag;
        $this->urlInterface = $urlInterface;
        $this->customerSession = $customerSession;
        $this->scopeConfig = $scopeConfig;
        $this->resultJsonFactory = $resultJsonFactory;
    }

    public function execute(Observer $observer)
    {

        $controller = $observer->getControllerAction();
        $resultJson = $this->resultJsonFactory->create();

        if (!$this->scopeConfig->getValue('filoblu_recaptcha/settings/newsletterajax_subscriber_newlandingaction')) {
            $url = $this->urlInterface->getUrl('newsletterajax/subscriber/newlandingaction', ['_secure' => true]);
            $controller->getResponse()->setRedirect($url);
            return;
        }


        if (!$this->validateInterface->validate()) {
            $this->messageManager->addError($this->helperData->getErrorDescription());
            $resultJson->setData(['success' => false, 'error' => true, 'message' => $this->helperData->getErrorDescription()]);
            $this->actionFlag->set('', Action::FLAG_NO_DISPATCH, true);
            return $resultJson;
        }
    }
}
